Django Nomadlytics — django-nomadlytics 0.1 documentation

### Navigation

- index
- next |
- django-nomadlytics 0.1 documentation »

# Django Nomadlytics

## Overview

This Django app offers a very light abstraction layer to use a single method of tracking your data into different SaaS analytics services such as Mixpanel, Google Analytics, or others.

Contents:

- Installation
  - Dependencies
  - Initial setup
- Configuration
  - Setup
  - Services
- Usage

### Navigation

- index
- next |
- django-nomadlytics 0.1 documentation »